aboutsummaryrefslogtreecommitdiff
path: root/src/analyzers/raids
diff options
context:
space:
mode:
Diffstat (limited to 'src/analyzers/raids')
-rw-r--r--src/analyzers/raids/mod.rs2
-rw-r--r--src/analyzers/raids/w6.rs10
2 files changed, 6 insertions, 6 deletions
diff --git a/src/analyzers/raids/mod.rs b/src/analyzers/raids/mod.rs
index bb3824b..a0602b0 100644
--- a/src/analyzers/raids/mod.rs
+++ b/src/analyzers/raids/mod.rs
@@ -19,7 +19,7 @@ mod w5;
pub use w5::{Dhuum, SoullessHorror};
mod w6;
-pub use w6::{ConjuredAmalgamate, LargosTwins, Qadim};
+pub use w6::{ConjuredAmalgamate, TwinLargos, Qadim};
mod w7;
pub use w7::{CardinalAdina, CardinalSabir, QadimThePeerless};
diff --git a/src/analyzers/raids/w6.rs b/src/analyzers/raids/w6.rs
index 8701a63..11fd02e 100644
--- a/src/analyzers/raids/w6.rs
+++ b/src/analyzers/raids/w6.rs
@@ -59,21 +59,21 @@ pub const LARGOS_CM_HEALTH: u64 = 19_200_000;
///
/// The CM is detected by the boss's health, which is higher in the challenge mote.
#[derive(Debug, Clone, Copy)]
-pub struct LargosTwins<'log> {
+pub struct TwinLargos<'log> {
log: &'log Log,
}
-impl<'log> LargosTwins<'log> {
- /// Create a new [`LargosTwins`] analyzer for the given log.
+impl<'log> TwinLargos<'log> {
+ /// Create a new [`TwinLargos`] analyzer for the given log.
///
/// **Do not** use this method unless you know what you are doing. Instead, rely on
/// [`Log::analyzer`]!
pub fn new(log: &'log Log) -> Self {
- LargosTwins { log }
+ TwinLargos { log }
}
}
-impl<'log> Analyzer for LargosTwins<'log> {
+impl<'log> Analyzer for TwinLargos<'log> {
fn log(&self) -> &Log {
self.log
}